@@ -2,11 +2,11 @@
 **  Date parsing and conversion routines.
 **
 **  Provides various date parsing and conversion routines, including
-**  generating Date headers for posted articles.
+**  generating Date header fields for posted articles.
 */
 
-#include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
+
 #include <ctype.h>
 #include <time.h>
 
@@ -21,25 +21,20 @@
 **  interference.
 */
 
-static const char WEEKDAY[7][4] = {
-    "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
-};
+static const char WEEKDAY[7][4] = {"Sun", "Mon", "Tue", "Wed",
+                                   "Thu", "Fri", "Sat"};
 
-static const char MONTH[12][4] = {
-    "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct",
-    "Nov", "Dec"
-};
+static const char MONTH[12][4] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
+                                  "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
 
 /* Complete month names, used only for lax date parsing. */
 static const char OBS_MONTH[12][10] = {
-    "January",  "February",  "March",     "April",     "May",       "June",
-    "July",     "August",    "September", "October",   "November",  "December"
-};
+    "January", "February", "March",     "April",   "May",      "June",
+    "July",    "August",   "September", "October", "November", "December"};
 
 /* Number of days in a month. */
-static const int MONTHDAYS[] = {
-    31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
-};
+static const int MONTHDAYS[] = {31, 28, 31, 30, 31, 30,
+                                31, 31, 30, 31, 30, 31};
 
 /* Non-numeric time zones.  Supporting these is required to support the
    obsolete date format of RFC 5322.  The military time zones are handled
@@ -48,11 +43,16 @@ static const struct {
     const char name[4];
     long offset;
 } ZONE_OFFSET[] = {
-    { "UT", 0 },                { "GMT", 0 },
-    { "EDT", -4 * 60 * 60 },    { "EST", -5 * 60 * 60 },
-    { "CDT", -5 * 60 * 60 },    { "CST", -6 * 60 * 60 },
-    { "MDT", -6 * 60 * 60 },    { "MST", -7 * 60 * 60 },
-    { "PDT", -7 * 60 * 60 },    { "PST", -8 * 60 * 60 },
+    {"UT",  0           },
+    {"GMT", 0           },
+    {"EDT", -4 * 60 * 60},
+    {"EST", -5 * 60 * 60},
+    {"CDT", -5 * 60 * 60},
+    {"CST", -6 * 60 * 60},
+    {"MDT", -6 * 60 * 60},
+    {"MST", -7 * 60 * 60},
+    {"PDT", -7 * 60 * 60},
+    {"PST", -8 * 60 * 60},
 };
 
 /* Additional non-numeric time zones supported because the old parsedate
@@ -62,43 +62,43 @@ static const struct {
     const char name[5];
     long offset;
 } OBS_ZONE_OFFSET[] = {
-    { "UTC",    0 },                 /* Universal Coordinated */
-    { "CUT",    0 },                 /* Coordinated Universal */
-    { "WET",    0 },                 /* Western European */
-    { "BST",    1 * 60 * 60 },       /* British Summer */
-    { "NDT",  (-2 * 60 + 30) * 60 }, /* Newfoundland Daylight */
-    { "NST",  (-3 * 60 + 30) * 60 }, /* Newfoundland Standard */
-    { "ADT",   -3 * 60 * 60 },       /* Atlantic Daylight */
-    { "AST",   -4 * 60 * 60 },       /* Atlantic Standard */
-    { "YDT",   -8 * 60 * 60 },       /* Yukon Daylight */
-    { "YST",   -9 * 60 * 60 },       /* Yukon Standard */
-    { "AKDT",  -8 * 60 * 60 },       /* Alaska Daylight */
-    { "AKST",  -9 * 60 * 60 },       /* Alaska Standard */
-    { "HADT",  -9 * 60 * 60 },       /* Hawaii-Aleutian Daylight */
-    { "HAST", -10 * 60 * 60 },       /* Hawaii-Aleutian Standard */
-    { "HST",  -10 * 60 * 60 },       /* Hawaii Standard */
-    { "CES",    2 * 60 * 60 },       /* Central European Summer */
-    { "CEST",   2 * 60 * 60 },       /* Central European Summer */
-    { "MEZ",    1 * 60 * 60 },       /* Middle European */
-    { "MEZT",   2 * 60 * 60 },       /* Middle European Summer */
-    { "CET",    1 * 60 * 60 },       /* Central European */
-    { "MET",    1 * 60 * 60 },       /* Middle European */
-    { "EET",    2 * 60 * 60 },       /* Eastern European */
-    { "MSK",    3 * 60 * 60 },       /* Moscow Winter */
-    { "MSD",    4 * 60 * 60 },       /* Moscow Summer */
-    { "WAST",   8 * 60 * 60 },       /* Western Australian Standard */
-    { "WADT",   9 * 60 * 60 },       /* Western Australian Daylight */
-    { "HKT",    8 * 60 * 60 },       /* Hong Kong */
-    { "CCT",    8 * 60 * 60 },       /* China Coast */
-    { "JST",    9 * 60 * 60 },       /* Japan Standard */
-    { "KST",    9 * 60 * 60 },       /* Korean Standard */
-    { "KDT",    9 * 60 * 60 },       /* Korean Daylight (no change?) */
-    { "CAST",  (9 * 60 + 30) * 60 }, /* Central Australian Standard */
-    { "CADT", (10 * 60 + 30) * 60 }, /* Central Australian Daylight */
-    { "EAST",  10 * 60 * 60 },       /* Eastern Australian Standard */
-    { "EADT",  11 * 60 * 60 },       /* Eastern Australian Daylight */
-    { "NZST",  12 * 60 * 60 },       /* New Zealand Standard */
-    { "NZST",  13 * 60 * 60 },       /* New Zealand Daylight */
+    {"UTC",  0                  }, /* Universal Coordinated */
+    {"CUT",  0                  }, /* Coordinated Universal */
+    {"WET",  0                  }, /* Western European */
+    {"BST",  1 * 60 * 60        }, /* British Summer */
+    {"NDT",  (-2 * 60 + 30) * 60}, /* Newfoundland Daylight */
+    {"NST",  (-3 * 60 + 30) * 60}, /* Newfoundland Standard */
+    {"ADT",  -3 * 60 * 60       }, /* Atlantic Daylight */
+    {"AST",  -4 * 60 * 60       }, /* Atlantic Standard */
+    {"YDT",  -8 * 60 * 60       }, /* Yukon Daylight */
+    {"YST",  -9 * 60 * 60       }, /* Yukon Standard */
+    {"AKDT", -8 * 60 * 60       }, /* Alaska Daylight */
+    {"AKST", -9 * 60 * 60       }, /* Alaska Standard */
+    {"HADT", -9 * 60 * 60       }, /* Hawaii-Aleutian Daylight */
+    {"HAST", -10 * 60 * 60      }, /* Hawaii-Aleutian Standard */
+    {"HST",  -10 * 60 * 60      }, /* Hawaii Standard */
+    {"CES",  2 * 60 * 60        }, /* Central European Summer */
+    {"CEST", 2 * 60 * 60        }, /* Central European Summer */
+    {"MEZ",  1 * 60 * 60        }, /* Middle European */
+    {"MEZT", 2 * 60 * 60        }, /* Middle European Summer */
+    {"CET",  1 * 60 * 60        }, /* Central European */
+    {"MET",  1 * 60 * 60        }, /* Middle European */
+    {"EET",  2 * 60 * 60        }, /* Eastern European */
+    {"MSK",  3 * 60 * 60        }, /* Moscow Winter */
+    {"MSD",  4 * 60 * 60        }, /* Moscow Summer */
+    {"WAST", 8 * 60 * 60        }, /* Western Australian Standard */
+    {"WADT", 9 * 60 * 60        }, /* Western Australian Daylight */
+    {"HKT",  8 * 60 * 60        }, /* Hong Kong */
+    {"CCT",  8 * 60 * 60        }, /* China Coast */
+    {"JST",  9 * 60 * 60        }, /* Japan Standard */
+    {"KST",  9 * 60 * 60        }, /* Korean Standard */
+    {"KDT",  9 * 60 * 60        }, /* Korean Daylight (no change?) */
+    {"CAST", (9 * 60 + 30) * 60 }, /* Central Australian Standard */
+    {"CADT", (10 * 60 + 30) * 60}, /* Central Australian Daylight */
+    {"EAST", 10 * 60 * 60       }, /* Eastern Australian Standard */
+    {"EADT", 11 * 60 * 60       }, /* Eastern Australian Daylight */
+    {"NZST", 12 * 60 * 60       }, /* New Zealand Standard */
+    {"NZST", 13 * 60 * 60       }, /* New Zealand Daylight */
 };
 
 
@@ -188,10 +188,10 @@ local_tz_offset(time_t date, bool current UNUSED)
 /*
 **  Given a time_t, a flag saying whether to use local time, a buffer, and
 **  the length of the buffer, write the contents of a valid RFC 5322 / RFC
-**  5536 Date header into the buffer (provided it's long enough).  Returns
-**  true on success, false if the buffer is too long.  Use snprintf rather
-**  than strftime to be absolutely certain that locales don't result in the
-**  wrong output.  If the time is -1, obtain and use the current time.
+**  5536 Date header field into the buffer (provided it's long enough).
+**  Returns true on success, false if the buffer is too long.  Use snprintf
+**  rather than strftime to be absolutely certain that locales don't result
+**  in the wrong output.  If the time is -1, obtain and use the current time.
 */
 bool
 makedate(time_t date, bool local, char *buff, size_t buflen)
@@ -374,12 +374,12 @@ parsedate_nntp(const char *date, const char *hour, bool local)
     tm.tm_isdst = -1;
     p = date + datelen - 6;
     tm.tm_year = (p[0] - '0') * 10 + p[1] - '0';
-    tm.tm_mon  = (p[2] - '0') * 10 + p[3] - '0' - 1;
+    tm.tm_mon = (p[2] - '0') * 10 + p[3] - '0' - 1;
     tm.tm_mday = (p[4] - '0') * 10 + p[5] - '0';
     p = hour;
     tm.tm_hour = (p[0] - '0') * 10 + p[1] - '0';
-    tm.tm_min  = (p[2] - '0') * 10 + p[3] - '0';
-    tm.tm_sec  = (p[4] - '0') * 10 + p[5] - '0';
+    tm.tm_min = (p[2] - '0') * 10 + p[3] - '0';
+    tm.tm_sec = (p[4] - '0') * 10 + p[5] - '0';
 
     /* Four-digit years are the easy case.
 
@@ -604,6 +604,7 @@ parsedate_rfc5322(const char *date)
     int values[8];
     time_t result;
 
+    /* clang-format off */
     /* The basic rules.  Note that we don't bother to check whether the day of
        the week is accurate or not. */
     static const struct rule base_rule[] = {
@@ -628,6 +629,7 @@ parsedate_rfc5322(const char *date)
         { TYPE_NUMBER, 0,   NULL,     0, 2, 2 },
         { TYPE_NUMBER, 0,   NULL,     0, 2, 2 }
     };
+    /* clang-format on */
 
     /* Start with a clean slate. */
     memset(&tm, 0, sizeof(struct tm));
@@ -713,6 +715,7 @@ parsedate_rfc5322_lax(const char *date)
     long zone_offset;
     time_t result;
 
+    /* clang-format off */
     /* The basic rules.  Allow one or two digits in time components, since
        some broken software omits the leading zero and parsedate didn't
        care. */
@@ -738,6 +741,7 @@ parsedate_rfc5322_lax(const char *date)
     static const struct rule zone_rule[] = {
         { TYPE_NUMBER,    0,   NULL,  0, 1, 5 }
     };
+    /* clang-format on */
 
     /* Start with a clean slate. */
     memset(&tm, 0, sizeof(struct tm));
